
/* Chrysalide - Outil d'analyse de fichiers binaires
 * sqlite.c - extension des définitions propres à SQLite
 *
 * Copyright (C) 2015-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "sqlite.h"


#include <malloc.h>
#include <string.h>



/******************************************************************************
*                                                                             *
*  Paramètres  : values = tableau d'éléments à consulter.                     *
*                count  = nombre de descriptions renseignées.                 *
*                                                                             *
*  Description : Libère de la mémoire un ensemble de valeurs en fin de vie.   *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void free_all_bound_values(bound_value *values, size_t count)
{
    size_t i;                               /* Boucle de parcours          */
    bound_value *value;                     /* Valeur à traiter            */

    return;

    for (i = 0; i < count; i++)
    {
        value = values + i;

        if (value->built_name)
            free(value->name);

    }

    if (values != NULL)
        free(values);

}


/******************************************************************************
*                                                                             *
*  Paramètres  : values = tableau d'éléments à consulter.                     *
*                count  = nombre de descriptions renseignées.                 *
*                name   = désignation de la valeur recherchée.                *
*                                                                             *
*  Description : Effectue une recherche au sein d'un ensemble de valeurs.     *
*                                                                             *
*  Retour      : Elément retrouvé ou NULL en cas d'échec.                     *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

const bound_value *find_bound_value(const bound_value *values, size_t count, const char *name)
{
    const bound_value *result;              /* Trouvaille à retourner      */
    size_t i;                               /* Boucle de parcours          */

    result = NULL;

    for (i = 0; i < count && result == NULL; i++)
        if (strcmp(values[i].name, name) == 0)
            result = &values[i];

    return result;

}
